#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bin
version:              0.1.4.1
visibility:           public
id:                   bin-0.1.4.1-FE7QafZsgS43wBCXiJVsSk
key:                  bin-0.1.4.1-FE7QafZsgS43wBCXiJVsSk
license:              GPL-2.0-or-later
copyright:            (c) 2019-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/vec
synopsis:             Bin: binary natural numbers.
description:
    This package provides /binary natural numbers/ ("Data.Bin");
    also utilities to work on the type level with @DataKinds@ ("Data.Type.Bin").

    @
    data Bin
    \    = BZ       -- ^ zero
    \    | BP BinP  -- ^ non-zero

    data BinP
    \    = BE       -- ^ one
    \    | B0 BinP  -- ^ double
    \    | B1 BinP  -- ^ double plus 1
    @

    There are /ordinals/ in "Data.Bin.Pos" module, as well as
    fixed width integers in "Data.Wrd".

    Another implementation is at <https://hackage.haskell.org/package/nat>,
    this differs in naming, and provides promoted variant.

category:             Data, Dependent Types, Singletons, Math
abi:                  060dacf9d9224fd885420c3bce8794c2
exposed:              True
exposed-modules:
    Data.Bin Data.Bin.Pos Data.BinP Data.BinP.PosP Data.Type.Bin
    Data.Type.BinP Data.Wrd

hidden-modules:       TrustworthyCompat
import-dirs:          /usr/lib/ghc-9.6.6/site-local/bin-0.1.4.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/bin-0.1.4.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/bin-0.1.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bin
hs-libraries:         HSbin-0.1.4.1-FE7QafZsgS43wBCXiJVsSk
depends:
    QuickCheck-2.15.0.1-KQOdD0ZF7G37LlS7pS23f7 base-4.18.2.1
    boring-0.2.2-95zAwRwmONjM683l7QC17 deepseq-1.4.8.1
    fin-0.3.2-BFzVtodb76zDn7FUCeHnlr
    hashable-1.4.7.0-Ws19qMM2f99bApawlWBTg
    some-1.0.6-FIfk4cSSsvfCiGo0eDPgfg

haddock-interfaces:   /usr/share/doc/haskell-bin/html/bin.haddock
haddock-html:         /usr/share/doc/haskell-bin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

